@@ -38,7 +38,7 @@ use crate::{
 /// # Example
 ///
 /// ```rust,no_run
-/// use ratatui::prelude::*;
+/// use ratatui::{backend::TermwizBackend, Terminal};
 ///
 /// let backend = TermwizBackend::new()?;
 /// let mut terminal = Terminal::new(backend)?;
@@ -78,7 +78,8 @@ impl TermwizBackend {
     /// # Example
     ///
     /// ```rust,no_run
-    /// # use ratatui::prelude::*;
+    /// use ratatui::backend::TermwizBackend;
+    ///
     /// let backend = TermwizBackend::new()?;
     /// # Ok::<(), Box<dyn std::error::Error>>(())
     /// ```
@@ -249,6 +250,52 @@ impl Backend for TermwizBackend {
             .map_err(|e| io::Error::new(io::ErrorKind::Other, e))?;
         Ok(())
     }
+
+    #[cfg(feature = "scrolling-regions")]
+    fn scroll_region_up(&mut self, region: std::ops::Range<u16>, amount: u16) -> io::Result<()> {
+        // termwiz doesn't have a command to just set the scrolling region. Instead, setting the
+        // scrolling region and scrolling are combined. However, this has the side-effect of
+        // leaving the scrolling region set. To reset the scrolling region, termwiz advises one to
+        // make a scrolling-region scroll command that contains the entire screen, but scrolls by 0
+        // lines. See [`Change::ScrollRegionUp`] for more details.
+        let (_, rows) = self.buffered_terminal.dimensions();
+        self.buffered_terminal.add_changes(vec![
+            Change::ScrollRegionUp {
+                first_row: region.start as usize,
+                region_size: region.len(),
+                scroll_count: amount as usize,
+            },
+            Change::ScrollRegionUp {
+                first_row: 0,
+                region_size: rows,
+                scroll_count: 0,
+            },
+        ]);
+        Ok(())
+    }
+
+    #[cfg(feature = "scrolling-regions")]
+    fn scroll_region_down(&mut self, region: std::ops::Range<u16>, amount: u16) -> io::Result<()> {
+        // termwiz doesn't have a command to just set the scrolling region. Instead, setting the
+        // scrolling region and scrolling are combined. However, this has the side-effect of
+        // leaving the scrolling region set. To reset the scrolling region, termwiz advises one to
+        // make a scrolling-region scroll command that contains the entire screen, but scrolls by 0
+        // lines. See [`Change::ScrollRegionDown`] for more details.
+        let (_, rows) = self.buffered_terminal.dimensions();
+        self.buffered_terminal.add_changes(vec![
+            Change::ScrollRegionDown {
+                first_row: region.start as usize,
+                region_size: region.len(),
+                scroll_count: amount as usize,
+            },
+            Change::ScrollRegionDown {
+                first_row: 0,
+                region_size: rows,
+                scroll_count: 0,
+            },
+        ]);
+        Ok(())
+    }
 }
 
 impl From<CellAttributes> for Style {
