@@ -1,7 +1,10 @@
-#![allow(deprecated)]
-
 use ratatui::{
-    backend::TestBackend, buffer::Buffer, layout::Rect, symbols, text::Line, widgets::Tabs,
+    backend::TestBackend,
+    buffer::Buffer,
+    layout::Rect,
+    style::{Style, Stylize},
+    symbols,
+    widgets::Tabs,
     Terminal,
 };
 
@@ -11,7 +14,7 @@ fn widgets_tabs_should_not_panic_on_narrow_areas() {
     let mut terminal = Terminal::new(backend).unwrap();
     terminal
         .draw(|f| {
-            let tabs = Tabs::new(["Tab1", "Tab2"].iter().cloned().map(Line::from).collect());
+            let tabs = Tabs::new(["Tab1", "Tab2"]);
             f.render_widget(
                 tabs,
                 Rect {
@@ -23,8 +26,7 @@ fn widgets_tabs_should_not_panic_on_narrow_areas() {
             );
         })
         .unwrap();
-    let expected = Buffer::with_lines(vec![" "]);
-    terminal.backend().assert_buffer(&expected);
+    terminal.backend().assert_buffer_lines([" "]);
 }
 
 #[test]
@@ -33,7 +35,7 @@ fn widgets_tabs_should_truncate_the_last_item() {
     let mut terminal = Terminal::new(backend).unwrap();
     terminal
         .draw(|f| {
-            let tabs = Tabs::new(["Tab1", "Tab2"].iter().cloned().map(Line::from).collect());
+            let tabs = Tabs::new(["Tab1", "Tab2"]);
             f.render_widget(
                 tabs,
                 Rect {
@@ -45,6 +47,7 @@ fn widgets_tabs_should_truncate_the_last_item() {
             );
         })
         .unwrap();
-    let expected = Buffer::with_lines(vec![format!(" Tab1 {} T ", symbols::line::VERTICAL)]);
+    let mut expected = Buffer::with_lines([format!(" Tab1 {} T ", symbols::line::VERTICAL)]);
+    expected.set_style(Rect::new(1, 0, 4, 1), Style::new().reversed());
     terminal.backend().assert_buffer(&expected);
 }
